@@ -6,7 +6,7 @@ import autoarray as aa
 
 from autoarray import exc
 from autoarray.dataset import abstract_dataset, preprocess
-from autoarray.structures import arrays, visibilities as vis, kernel
+from autoarray.structures import arrays, grids, visibilities as vis, kernel
 from autoarray.operators import transformer
 
 
@@ -15,23 +15,22 @@ logger = logging.getLogger(__name__)
 
 class Interferometer(abstract_dataset.AbstractDataset):
     def __init__(
-        self, visibilities, noise_map, uv_wavelengths, primary_beam=None, name=None
+        self,
+        visibilities,
+        noise_map,
+        uv_wavelengths,
+        primary_beam=None,
+        positions=None,
+        name=None,
     ):
 
-        super().__init__(data=visibilities, noise_map=noise_map, name=name)
+        super().__init__(
+            data=visibilities, noise_map=noise_map, positions=positions, name=name
+        )
 
         self.uv_wavelengths = uv_wavelengths
         self.primary_beam = primary_beam
 
-    @classmethod
-    def manual(cls, visibilities, noise_map, uv_wavelengths, primary_beam=None):
-        return Interferometer(
-            visibilities=visibilities,
-            noise_map=noise_map,
-            uv_wavelengths=uv_wavelengths,
-            primary_beam=primary_beam,
-        )
-
     @classmethod
     def from_fits(
         cls,
@@ -43,6 +42,7 @@ class Interferometer(abstract_dataset.AbstractDataset):
         uv_wavelengths_hdu=0,
         primary_beam_path=None,
         primary_beam_hdu=0,
+        positions_path=None,
     ):
         """Factory for loading the interferometer data_type from .fits files, as well as computing properties like the noise-map,
         exposure-time map, etc. from the interferometer-data_type.
@@ -73,11 +73,20 @@ class Interferometer(abstract_dataset.AbstractDataset):
         else:
             primary_beam = None
 
+        if positions_path is not None:
+
+            positions = grids.GridCoordinates.from_file(file_path=positions_path)
+
+        else:
+
+            positions = None
+
         return Interferometer(
             visibilities=visibilities,
             primary_beam=primary_beam,
             noise_map=noise_map,
             uv_wavelengths=uv_wavelengths,
+            positions=positions,
         )
 
     @property
@@ -148,9 +157,13 @@ class MaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
         interferometer,
         visibilities_mask,
         real_space_mask,
+        grid_class=grids.GridIterate,
+        grid_inversion_class=grids.Grid,
+        fractional_accuracy=0.9999,
+        sub_steps=None,
+        pixel_scales_interp=None,
         transformer_class=transformer.TransformerNUFFT,
         primary_beam_shape_2d=None,
-        pixel_scale_interpolation_grid=None,
         inversion_pixel_limit=None,
         inversion_uses_border=True,
         renormalize_primary_beam=True,
@@ -177,7 +190,7 @@ class MaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
         positions : [[]]
             Lists of image-pixel coordinates (arc-seconds) that mappers close to one another in the source-plane(s), \
             used to speed up the non-linear sampling.
-        pixel_scale_interpolation_grid : float
+        pixel_scales_interp : float
             If *True*, expensive to compute mass profile deflection angles will be computed on a sparse grid and \
             interpolated to the grid, sub and blurring grids.
         inversion_pixel_limit : int or None
@@ -185,10 +198,14 @@ class MaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
             up run.
         """
 
-        super(MaskedInterferometer, self).__init__(
+        super().__init__(
             dataset=interferometer,
             mask=real_space_mask,
-            pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
+            grid_class=grid_class,
+            grid_inversion_class=grid_inversion_class,
+            fractional_accuracy=fractional_accuracy,
+            sub_steps=sub_steps,
+            pixel_scales_interp=pixel_scales_interp,
             inversion_pixel_limit=inversion_pixel_limit,
             inversion_uses_border=inversion_uses_border,
         )
@@ -239,6 +256,14 @@ class MaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
     def signal_to_noise_map(self):
         return self.visibilities / self.noise_map
 
+    def modify_noise_map(self, noise_map):
+
+        masked_interferometer = copy.deepcopy(self)
+
+        masked_interferometer.noise_map = noise_map
+
+        return masked_interferometer
+
 
 class SimulatorInterferometer:
     def __init__(
