@@ -35,16 +35,16 @@ class Array(abstract_array.AbstractArray):
         Below is a visual illustration of a array, where a total of 10 pixels are unmasked and are included in \
         the array.
 
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|     This is an example mask.Mask, where:
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|o|o|x|x|x|x|     x = True (Pixel is masked and excluded from the array)
-        |x|x|x|o|o|o|o|x|x|x|     o = False (Pixel is not masked and included in the array)
-        |x|x|x|o|o|o|o|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI     This is an example mask.Mask, where:
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIoIoIxIxIxIxI     x = True (Pixel is masked and excluded from the array)
+        IxIxIxIoIoIoIoIxIxIxI     o = False (Pixel is not masked and included in the array)
+        IxIxIxIoIoIoIoIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
 
         The mask pixel index's will come out like this (and the direction of scaled values is highlighted
         around the mask.
@@ -53,16 +53,16 @@ class Array(abstract_array.AbstractArray):
 
         <--- -ve  x  +ve -->
                                                         y      x
-        |x|x|x|x|x|x|x|x|x|x|  ^   array[0] = 0
-        |x|x|x|x|x|x|x|x|x|x|  |   array[1] = 1
-        |x|x|x|x|x|x|x|x|x|x|  |   array[2] = 2
-        |x|x|x|x|0|1|x|x|x|x| +ve  array[3] = 3
-        |x|x|x|2|3|4|5|x|x|x|  y   array[4] = 4
-        |x|x|x|6|7|8|9|x|x|x| -ve  array[5] = 5
-        |x|x|x|x|x|x|x|x|x|x|  |   array[6] = 6
-        |x|x|x|x|x|x|x|x|x|x|  |   array[7] = 7
-        |x|x|x|x|x|x|x|x|x|x| \/   array[8] = 8
-        |x|x|x|x|x|x|x|x|x|x|      array[9] = 9
+        IxIxIxIxIxIxIxIxIxIxI  ^   array[0] = 0
+        IxIxIxIxIxIxIxIxIxIxI  I   array[1] = 1
+        IxIxIxIxIxIxIxIxIxIxI  I   array[2] = 2
+        IxIxIxIxI0I1IxIxIxIxI +ve  array[3] = 3
+        IxIxIxI2I3I4I5IxIxIxI  y   array[4] = 4
+        IxIxIxI6I7I8I9IxIxIxI -ve  array[5] = 5
+        IxIxIxIxIxIxIxIxIxIxI  I   array[6] = 6
+        IxIxIxIxIxIxIxIxIxIxI  I   array[7] = 7
+        IxIxIxIxIxIxIxIxIxIxI \/   array[8] = 8
+        IxIxIxIxIxIxIxIxIxIxI      array[9] = 9
 
         Case 2: [sub-size>1, store_in_1d=True]:
         ------------------
@@ -82,16 +82,16 @@ class Array(abstract_array.AbstractArray):
         contrast to the array above, our illustration below restricts the mask to just 2 pixels, to keep the
         illustration brief.
 
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|     This is an example mask.Mask, where:
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|     x = True (Pixel is masked and excluded from lens)
-        |x|x|x|x|o|o|x|x|x|x|     o = False (Pixel is not masked and included in lens)
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI     This is an example mask.Mask, where:
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI     x = True (Pixel is masked and excluded from lens)
+        IxIxIxIxIoIoIxIxIxIxI     o = False (Pixel is not masked and included in lens)
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
 
         Our array with a sub-size looks like it did before:
 
@@ -99,16 +99,16 @@ class Array(abstract_array.AbstractArray):
 
         <--- -ve  x  +ve -->
 
-        |x|x|x|x|x|x|x|x|x|x|  ^
-        |x|x|x|x|x|x|x|x|x|x|  |
-        |x|x|x|x|x|x|x|x|x|x|  |
-        |x|x|x|x|x|x|x|x|x|x| +ve
-        |x|x|x|0|1|x|x|x|x|x|  y
-        |x|x|x|x|x|x|x|x|x|x| -ve
-        |x|x|x|x|x|x|x|x|x|x|  |
-        |x|x|x|x|x|x|x|x|x|x|  |
-        |x|x|x|x|x|x|x|x|x|x| \/
-        |x|x|x|x|x|x|x|x|x|x|
+        IxIxIxIxIxIxIxIxIxIxI  ^
+        IxIxIxIxIxIxIxIxIxIxI  I
+        IxIxIxIxIxIxIxIxIxIxI  I
+        IxIxIxIxIxIxIxIxIxIxI +ve
+        IxIxIxI0I1IxIxIxIxIxI  y
+        IxIxIxIxIxIxIxIxIxIxI -ve
+        IxIxIxIxIxIxIxIxIxIxI  I
+        IxIxIxIxIxIxIxIxIxIxI  I
+        IxIxIxIxIxIxIxIxIxIxI \/
+        IxIxIxIxIxIxIxIxIxIxI
 
         However, if the sub-size is 2,each unmasked pixel has a set of sub-pixels with values. For example, for pixel 0,
         if *sub_size=2*, it has 4 values on a 2x2 sub-array:
@@ -116,8 +116,8 @@ class Array(abstract_array.AbstractArray):
         Pixel 0 - (2x2):
 
                array[0] = value of first sub-pixel in pixel 0.
-        |0|1|  array[1] = value of first sub-pixel in pixel 1.
-        |2|3|  array[2] = value of first sub-pixel in pixel 2.
+        I0I1I  array[1] = value of first sub-pixel in pixel 1.
+        I2I3I  array[2] = value of first sub-pixel in pixel 2.
                array[3] = value of first sub-pixel in pixel 3.
 
         If we used a sub_size of 3, for the first pixel we we would create a 3x3 sub-array:
@@ -126,9 +126,9 @@ class Array(abstract_array.AbstractArray):
                  array[0] = value of first sub-pixel in pixel 0.
                  array[1] = value of first sub-pixel in pixel 1.
                  array[2] = value of first sub-pixel in pixel 2.
-        |0|1|2|  array[3] = value of first sub-pixel in pixel 3.
-        |3|4|5|  array[4] = value of first sub-pixel in pixel 4.
-        |6|7|8|  array[5] = value of first sub-pixel in pixel 5.
+        I0I1I2I  array[3] = value of first sub-pixel in pixel 3.
+        I3I4I5I  array[4] = value of first sub-pixel in pixel 4.
+        I6I7I8I  array[5] = value of first sub-pixel in pixel 5.
                  array[6] = value of first sub-pixel in pixel 6.
                  array[7] = value of first sub-pixel in pixel 7.
                  array[8] = value of first sub-pixel in pixel 8.
@@ -143,16 +143,16 @@ class Array(abstract_array.AbstractArray):
 
         For the following example mask:
 
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|     This is an example mask.Mask, where:
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|o|o|x|x|x|x|     x = True (Pixel is masked and excluded from the array)
-        |x|x|x|o|o|o|o|x|x|x|     o = False (Pixel is not masked and included in the array)
-        |x|x|x|o|o|o|o|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
-        |x|x|x|x|x|x|x|x|x|x|
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI     This is an example mask.Mask, where:
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIoIoIxIxIxIxI     x = True (Pixel is masked and excluded from the array)
+        IxIxIxIoIoIoIoIxIxIxI     o = False (Pixel is not masked and included in the array)
+        IxIxIxIoIoIoIoIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
+        IxIxIxIxIxIxIxIxIxIxI
 
         - array[0,0] = 0.0 (it is masked, thus zero)
         - array[0,0] = 0.0 (it is masked, thus zero)
