@@ -641,63 +641,39 @@ def sub_grid_2d_from(sub_grid_1d, mask, sub_size):
 
 
 @decorator_util.jit()
-def quadrant_from_coordinate(coordinate):
+def grid_upscaled_1d_from(grid_1d, upscale_factor, pixel_scales):
 
-    if coordinate[0] >= 0.0 and coordinate[1] <= 0.0:
-        return 0
-    elif coordinate[0] >= 0.0 and coordinate[1] >= 0.0:
-        return 1
-    elif coordinate[0] <= 0.0 and coordinate[1] <= 0.0:
-        return 2
-    elif coordinate[0] <= 0.0 and coordinate[1] >= 0.0:
-        return 3
+    grid_upscaled_1d = np.zeros(shape=(grid_1d.shape[0] * upscale_factor ** 2, 2))
 
+    upscale_index = 0
 
-@decorator_util.jit()
-def positions_at_coordinate_from(grid_2d, coordinate, mask=None):
+    y_upscale_half = pixel_scales[0] / 2
+    y_upscale_step = pixel_scales[0] / upscale_factor
 
-    if mask is None:
-        mask = np.full(fill_value=False, shape=(grid_2d.shape[0], grid_2d.shape[1]))
+    x_upscale_half = pixel_scales[1] / 2
+    x_upscale_step = pixel_scales[1] / upscale_factor
 
-    grid_shifted = np.zeros(shape=grid_2d.shape)
+    for grid_index in range(grid_1d.shape[0]):
 
-    grid_shifted[:, :, 0] = grid_2d[:, :, 0] - coordinate[0]
-    grid_shifted[:, :, 1] = grid_2d[:, :, 1] - coordinate[1]
+        y_grid = grid_1d[grid_index, 0]
+        x_grid = grid_1d[grid_index, 1]
 
-    pixels_at_coordinate = []
+        for y in range(upscale_factor):
+            for x in range(upscale_factor):
 
-    for y in range(1, grid_2d.shape[0] - 1):
-        for x in range(1, grid_2d.shape[1] - 1):
-            if not mask[y, x] and not mask_util.check_if_edge_pixel(
-                mask=mask, y=y, x=x
-            ):
-
-                top_left_quadrant = quadrant_from_coordinate(
-                    coordinate=grid_shifted[y + 1, x - 1, :]
+                grid_upscaled_1d[upscale_index, 0] = (
+                    y_grid
+                    + y_upscale_half
+                    - y * y_upscale_step
+                    - (y_upscale_step / 2.0)
                 )
-                top_right_quadrant = quadrant_from_coordinate(
-                    coordinate=grid_shifted[y + 1, x + 1, :]
-                )
-                bottom_left_quadrant = quadrant_from_coordinate(
-                    coordinate=grid_shifted[y - 1, x - 1, :]
-                )
-                bottom_right_quadrant = quadrant_from_coordinate(
-                    coordinate=grid_shifted[y - 1, x + 1, :]
+                grid_upscaled_1d[upscale_index, 1] = (
+                    x_grid
+                    - x_upscale_half
+                    + x * x_upscale_step
+                    + (x_upscale_step / 2.0)
                 )
 
-                if (
-                    top_left_quadrant
-                    + top_right_quadrant
-                    + bottom_left_quadrant
-                    + bottom_right_quadrant
-                ) == 6:
-                    if (
-                        top_left_quadrant
-                        != top_right_quadrant
-                        != bottom_left_quadrant
-                        != bottom_right_quadrant
-                    ):
+                upscale_index += 1
 
-                        pixels_at_coordinate.append((y, x))
-
-    return pixels_at_coordinate
+    return grid_upscaled_1d
