@@ -10,7 +10,7 @@ class TestUnmaskedSparseForSparse:
     ):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -21,14 +21,14 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2], [2, 0], [2, 1], [2, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from_mask_2d(
-            mask_2d=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
-        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from_mask_2d_and_pixel_centres(
+        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from(
             total_sparse_pixels=total_masked_pixels,
-            mask_2d=ma,
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -41,7 +41,7 @@ class TestUnmaskedSparseForSparse:
     ):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -52,14 +52,14 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [2, 2], [1, 1], [0, 2], [2, 0], [0, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from_mask_2d(
-            mask_2d=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
-        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from_mask_2d_and_pixel_centres(
+        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from(
             total_sparse_pixels=total_masked_pixels,
-            mask_2d=ma,
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -68,7 +68,7 @@ class TestUnmaskedSparseForSparse:
     def test__mask_is_cross__some_pix_pixels_are_masked__omitted_from_mapping(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[True, False, True], [False, False, False], [True, False, True]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -79,14 +79,14 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2], [2, 0], [2, 1], [2, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from_mask_2d(
-            mask_2d=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
-        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from_mask_2d_and_pixel_centres(
+        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from(
             total_sparse_pixels=total_masked_pixels,
-            mask_2d=ma,
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -95,7 +95,7 @@ class TestUnmaskedSparseForSparse:
     def test__same_as_above__different_mask_and_centres(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[False, False, True], [False, False, False], [True, False, False]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -106,14 +106,14 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from_mask_2d(
-            mask_2d=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
-        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from_mask_2d_and_pixel_centres(
+        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from(
             total_sparse_pixels=total_masked_pixels,
-            mask_2d=ma,
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -122,7 +122,7 @@ class TestUnmaskedSparseForSparse:
     def test__same_as_above__but_3x4_mask(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, False, True],
                     [False, False, False, False],
@@ -137,14 +137,14 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1], [2, 3], [2, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from_mask_2d(
-            mask_2d=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
-        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from_mask_2d_and_pixel_centres(
+        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from(
             total_sparse_pixels=total_masked_pixels,
-            mask_2d=ma,
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -153,7 +153,7 @@ class TestUnmaskedSparseForSparse:
     def test__same_as_above__but_4x3_mask(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, False, True],
                     [True, False, True],
@@ -169,14 +169,14 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1], [2, 2], [3, 1]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from_mask_2d(
-            mask_2d=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
-        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from_mask_2d_and_pixel_centres(
+        unmasked_sparse_for_sparse = aa.util.sparse.unmasked_sparse_for_sparse_from(
             total_sparse_pixels=total_masked_pixels,
-            mask_2d=ma,
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -189,7 +189,7 @@ class TestSparseForUnmaskedSparse:
     ):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -200,8 +200,8 @@ class TestSparseForUnmaskedSparse:
             [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2], [2, 0], [2, 1], [2, 2]]
         )
 
-        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from_mask_2d_and_pixel_centres(
-            mask_2d=ma,
+        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
             total_sparse_pixels=9,
         )
@@ -215,7 +215,7 @@ class TestSparseForUnmaskedSparse:
     ):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -226,8 +226,8 @@ class TestSparseForUnmaskedSparse:
             [[0, 0], [0, 1], [2, 2], [1, 1], [0, 2], [2, 0], [0, 2]]
         )
 
-        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from_mask_2d_and_pixel_centres(
-            mask_2d=ma,
+        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
             total_sparse_pixels=9,
         )
@@ -237,7 +237,7 @@ class TestSparseForUnmaskedSparse:
     def test__mask_is_cross__some_pix_pixels_are_masked__omitted_from_mapping(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[True, False, True], [False, False, False], [True, False, True]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -248,8 +248,8 @@ class TestSparseForUnmaskedSparse:
             [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2], [2, 0], [2, 1], [2, 2]]
         )
 
-        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from_mask_2d_and_pixel_centres(
-            mask_2d=ma,
+        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
             total_sparse_pixels=5,
         )
@@ -261,7 +261,7 @@ class TestSparseForUnmaskedSparse:
     def test__same_as_above__different_mask_and_centres(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[False, False, True], [False, False, False], [True, False, False]]
             ),
             pixel_scales=(1.0, 1.0),
@@ -272,8 +272,8 @@ class TestSparseForUnmaskedSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1]]
         )
 
-        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from_mask_2d_and_pixel_centres(
-            mask_2d=ma,
+        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
             total_sparse_pixels=4,
         )
@@ -283,7 +283,7 @@ class TestSparseForUnmaskedSparse:
     def test__same_as_above__but_3x4_mask(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, False, True],
                     [False, False, False, False],
@@ -298,8 +298,8 @@ class TestSparseForUnmaskedSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1], [2, 3], [0, 2]]
         )
 
-        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from_mask_2d_and_pixel_centres(
-            mask_2d=ma,
+        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
             total_sparse_pixels=5,
         )
@@ -309,7 +309,7 @@ class TestSparseForUnmaskedSparse:
     def test__same_as_above__but_4x3_mask(self):
 
         ma = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, False, True],
                     [True, False, True],
@@ -325,8 +325,8 @@ class TestSparseForUnmaskedSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1], [2, 2], [3, 1]]
         )
 
-        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from_mask_2d_and_pixel_centres(
-            mask_2d=ma,
+        sparse_for_unmasked_sparse = aa.util.sparse.sparse_for_unmasked_sparse_from(
+            mask=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
             total_sparse_pixels=6,
         )
@@ -341,7 +341,7 @@ class TestRegularToSparse:
 
         regular_to_unmasked_sparse = np.array([0, 1, 2, 3, 4])
         sparse_for_unmasked_sparse = np.array([0, 1, 2, 3, 4])
-        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from_sparse_mappings(
+        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
             regular_to_unmasked_sparse=regular_to_unmasked_sparse,
             sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
@@ -350,7 +350,7 @@ class TestRegularToSparse:
 
         regular_to_unmasked_sparse = np.array([0, 1, 2, 3, 4])
         sparse_for_unmasked_sparse = np.array([0, 1, 5, 7, 18])
-        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from_sparse_mappings(
+        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
             regular_to_unmasked_sparse=regular_to_unmasked_sparse,
             sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
@@ -359,7 +359,7 @@ class TestRegularToSparse:
 
         regular_to_unmasked_sparse = np.array([1, 1, 1, 1, 2])
         sparse_for_unmasked_sparse = np.array([0, 10, 15, 3, 4])
-        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from_sparse_mappings(
+        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
             regular_to_unmasked_sparse=regular_to_unmasked_sparse,
             sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
@@ -370,7 +370,7 @@ class TestRegularToSparse:
 
         regular_to_unmasked_sparse = np.array([5, 6, 7, 8, 9])
         sparse_for_unmasked_sparse = np.array([0, 1, 2, 3, 4, 19, 18, 17, 16, 15])
-        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from_sparse_mappings(
+        sparse_1d_index_for_mask_1d_index = aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
             regular_to_unmasked_sparse=regular_to_unmasked_sparse,
             sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
@@ -389,7 +389,7 @@ class TestSparseGridFromUnmaskedSparseGrid:
             [[0.0, 0.0], [1.0, 1.0], [2.0, 2.0], [3.0, 3.0]]
         )
         unmasked_sparse_for_sparse = np.array([0, 1, 2, 3])
-        pix_grid = aa.util.sparse.sparse_grid_from_unmasked_sparse_grid(
+        pix_grid = aa.util.sparse.sparse_grid_via_unmasked_from(
             unmasked_sparse_grid=unmasked_sparse_grid,
             unmasked_sparse_for_sparse=unmasked_sparse_for_sparse,
         )
@@ -402,7 +402,7 @@ class TestSparseGridFromUnmaskedSparseGrid:
             [[0.0, 0.0], [4.0, 5.0], [2.0, 2.0], [8.0, 7.0]]
         )
         unmasked_sparse_for_sparse = np.array([0, 1, 2, 3])
-        pix_grid = aa.util.sparse.sparse_grid_from_unmasked_sparse_grid(
+        pix_grid = aa.util.sparse.sparse_grid_via_unmasked_from(
             unmasked_sparse_grid=unmasked_sparse_grid,
             unmasked_sparse_for_sparse=unmasked_sparse_for_sparse,
         )
@@ -415,7 +415,7 @@ class TestSparseGridFromUnmaskedSparseGrid:
             [[0.0, 0.0], [4.0, 5.0], [2.0, 2.0], [8.0, 7.0]]
         )
         unmasked_sparse_for_sparse = np.array([1, 0, 3, 2])
-        pix_grid = aa.util.sparse.sparse_grid_from_unmasked_sparse_grid(
+        pix_grid = aa.util.sparse.sparse_grid_via_unmasked_from(
             unmasked_sparse_grid=unmasked_sparse_grid,
             unmasked_sparse_for_sparse=unmasked_sparse_for_sparse,
         )
@@ -432,7 +432,7 @@ class TestSparseGridFromUnmaskedSparseGrid:
             [[0.0, 0.0], [1.0, 1.0], [2.0, 2.0], [3.0, 3.0]]
         )
         unmasked_sparse_for_sparse = np.array([1, 2])
-        pix_grid = aa.util.sparse.sparse_grid_from_unmasked_sparse_grid(
+        pix_grid = aa.util.sparse.sparse_grid_via_unmasked_from(
             unmasked_sparse_grid=unmasked_sparse_grid,
             unmasked_sparse_for_sparse=unmasked_sparse_for_sparse,
         )
@@ -443,7 +443,7 @@ class TestSparseGridFromUnmaskedSparseGrid:
             [[0.0, 0.0], [4.0, 5.0], [2.0, 2.0], [8.0, 7.0]]
         )
         unmasked_sparse_for_sparse = np.array([2, 2, 3])
-        pix_grid = aa.util.sparse.sparse_grid_from_unmasked_sparse_grid(
+        pix_grid = aa.util.sparse.sparse_grid_via_unmasked_from(
             unmasked_sparse_grid=unmasked_sparse_grid,
             unmasked_sparse_for_sparse=unmasked_sparse_for_sparse,
         )
@@ -461,7 +461,7 @@ class TestSparseGridFromUnmaskedSparseGrid:
             ]
         )
         unmasked_sparse_for_sparse = np.array([1, 0, 5, 2])
-        pix_grid = aa.util.sparse.sparse_grid_from_unmasked_sparse_grid(
+        pix_grid = aa.util.sparse.sparse_grid_via_unmasked_from(
             unmasked_sparse_grid=unmasked_sparse_grid,
             unmasked_sparse_for_sparse=unmasked_sparse_for_sparse,
         )
